From 2a45830a58aee15cf446b23c0a01925566981c8f Mon Sep 17 00:00:00 2001
From: Tyler Spivey <tspivey@pcdesk.net>
Date: Mon, 12 Jan 2015 19:56:52 -0800
Subject: [PATCH] Ignore URLs that start with data:image/

If an image has no alt text and we're getting its name from the URL,
return an empty string if the URL starts with data:image/
Fixes #4793
---
 nvdaHelper/vbufBase/utils.cpp | 5 +++++
 1 file changed, 5 insertions(+)

diff --git a/nvdaHelper/vbufBase/utils.cpp b/nvdaHelper/vbufBase/utils.cpp
index 25a1bce..fbbd13d 100644
--- a/nvdaHelper/vbufBase/utils.cpp
+++ b/nvdaHelper/vbufBase/utils.cpp
@@ -28,6 +28,11 @@ wstring getNameForURL(const wstring &url) {
 	if (colonPos != wstring::npos && url.compare(colonPos, 3, L"://") != 0) {
 		// This URL specifies a protocol, but it is not a path-based protocol; e.g. it is a javascript: or mailto: URL.
 		// Return the URL as is with the protocol stripped.
+		// Unless it is data:image/*, which is not useful.
+		wstring imgCheck = url.substr(0, 11);
+		transform(imgCheck.begin(), imgCheck.end(), imgCheck.begin(), tolower);
+		if (imgCheck.compare(0, 11, L"data:image/") == 0)
+			return L"";
 		return url.substr(colonPos + 1);
 	}
 
-- 
1.9.5.msysgit.0

